! Ralf Becker
! DLR-AT
! $Id: uslag1.f90,v 1.2 2010/06/02 14:36:58 beck_rf Exp $
!-------------------------------------------------------------------------------
subroutine uslag1
! This is one of the two subroutines which must be completed in the case of a 
! calculation modeling a lagrangian multiphasic flow. This subroutine gathers 
! in different headings all the key word which are necessary to configure the 
! lagrangian module. The different headings refer to:
! - the global configuration parameters 
! - the specific physical models describing the particle behaviour 
! - the backward coupling (influence of the dispersed phase on the continuous 
!   phase) 
! - the numerical parameters 
! - the volumetric statistics 
! - the boundary statistics 
! - the postprocessing in trajectory mode
!

implicit none

!=======================================================================
!     DONNEES EN COMMON
!=======================================================================

include "paramx.h"
include "entsor.h"
include "lagdim.h"
include "lagpar.h"
include "lagran.h"
include "ihmpre.h"

!=======================================================================
! VARIABLES LOCALES

integer          ii,ipv,icha
double precision sio2 , al2o3 , fe2o3 , cao

!=======================================================================


!===============================================================================
! 1. Usage of Lagrangian module
!===============================================================================
!     IILAGR
!     = 0 not activated
!     = 1 Lagrangian two-phase flow in one-way coupling 
!       (no influence of the particles on the continuous phase)
!     = 2 Lagrangian two-phase flow with two-way coupling 
!       (influence of the particles on the dynamics of the continuous phase). 
!       It must be noted that the two-way coupling is taken into account only 
!       for the first eulerian phase. Dynamics, temperature and mass may be 
!       coupled independently
!     = 3 Lagrangian two-phase flow on frozen continuous phase. 
!       This option can only be used in case of a calculation restart (ISUITE = 1). 
!       All the eulerian fields are frozen (including the scalar fields). 
!       This option automatically implies ICCVFG = 1

iilagr = 2

!===============================================================================
! 2. Calculation restart
!===============================================================================
!     ISUILA 
!     activation (=1) or not (=0) of a Lagrangian calculation restart. 
!     The calculation restart file read when this option is activated (FICAML) 
!     only contains the data related to the particles (see also ISUIST)
!     the global calculation must also be a restart calculation (ISUITE=1)

isuila = 0

!     during a Lagrangian calculation restart, indicates whether the particle 
!     statistics (volume and boundary) and two-way coupling terms are to be read 
!     from a restart file (=1) or reinitialised (=0). The file to be read is FICMLS
!     useful if ISUILA = 1

if (isuila.eq.1) isuist = 1

!=======================================================================
! 3. Physical Models
!=======================================================================

!     IPHYLA activates (>0) or deactivates (=0) the physical models 
!     associated to the particles:
!     = 1: allows to associate with the particles evolution equations on their 
!          temperature (in degrees Celsius), their diameter and their mass
!     = 2: the particles are pulverised coal particles. Evolution equations on 
!          temperature (in degree Celsius), mass of reactive coal, mass of char 
!          and diameter of the shrinking core are associated with the particles. 
!          This option is available only if the continuous phase represents a 
!          pulverised coal flame
!     = 3: droplet evaporation 
!          
iphyla = 1

! 3.1 Options for temperature, diameter, mass (useful if IPHYLA = 1)
! --------------------------------------------------------------------

if (iphyla.eq.1) then

! evolution equation for the diameter
! 0 - none, 1 - yes

  idpvar =0 

! evolution equation for the particle temperature
! 0 - none, 1 - yes
  itpvar = 0

! evolution equation for the particle mass
! 0 - none, 1 - yes
  impvar = 1

endif

! TPART  [700.D0] initialisation temperature (in degree Celsius) 
! for the particles already present in the calculation domain when an 
! evolution equation on the particle temperature is activated during a 
! calculation restart (IPHYLA = 1 and ITPVAR = 1)
! useful if ISUILA = 1 and ITPVAR = 0 in the previous calculation
! CPPART [5200.D0] initialisation value for the specific heat (J.kg-1.K-1) 
! of the particles already present in the calculation domain when an 
! evolution equation on the particle temperature is activated during a 
! calculation (IPHYLA = 1 and ITPVAR = 1)
! useful if ISUILA = 1 and ITPVAR = 0 in the previous calculation
if (isuila.eq.1 .and. iphyla.eq.1 .and. itpvar.eq.1) then
        TPART  = 20.D0
        CPPART = 2133.D0
endif
!

! Options for fouling of coal particles
! RAPPORTS EDF/R&D DE REFERENCE : HI-81/00/030/A
!
if (iphyla.eq.2) then

!       IENCRA = 0 deactivate fouling
!              = 1 activate fouling
iencra = 0

! Definitions for each of the NCHAB coals

icha = 1
!
!       TPRENC : limit temperature (in degree Celsius) below which the coal particles 
!                do not cause any fouling (if the fouling model is activated) 
!
tprenc(icha) = 600.d0
!
!       VISREF : ash critical viscosity in kg/m/s, in the fouling model
!
visref(icha) = 10000.d0

!              VISREF
!     P(Tp) = --------   pour VISCEN >= VISREF
!              VISCEN

!           = 1 sinon

!     Pour evaluer la viscosite des cendres VISCEN, on utilise
!     l'expression de J.D. Watt et T.Fereday (J.Inst.Fuel-Vol42-p99)

!                         ENC1 * 1.0D+7
!     Log  (10*VISCEN) = --------------- + ENC2
!        10                            2
!                        (Tp(C) - 150)

!     La viscosite critique VISREF est donne par la litterature et
!     peut varier entre 8 Pa.set 1.D7 Pa.s           !
!     En general on prend 1.0D+4 Pa.s...
! Example for the composition of coal out of different minerals
! SiO2 + Al2O3 + Fe2O3 + CaO + MgO = 100% Mass
!
sio2   =  36.0d0
al2o3  =  20.8d0
fe2o3  =   4.9d0
cao    =  13.3d0
!
!       ENC1 et ENC2 : coefficients for the equation of Watt et Fereday
!
enc1(icha) = 0.00835d0 * sio2 + 0.00601d0 * al2o3 - 0.109d0
!
enc2(icha) = 0.0415d0 * sio2  + 0.0192d0 * al2o3 &
         + 0.0276d0 * fe2o3 + 0.016 * cao - 3.92d0
!
endif ! iphyla .eq.2 

!===============================================================================
! 4. maximal number of particles in the domaine
!===============================================================================

! Maximum number of particles simultaneously acceptable in the calculation domain.
! 

nbpmax = 1000000

!===============================================================================
! 5. options for the treatment of the dispersed phase
!===============================================================================
!
! supplementary variables for particles
!
!     * the supplementary variables are stored in  ETTP et ETTPA,
!     * NVLS - Number of variables describing the supplementary user particles 
!              for which a SDE is solved (stochastic differential equation)
!     * NUSVAR = 10 max. length of each name (defined in lagpar.h)
!     * JVLS(n) the nth supplementary user variable 
!
!     actual time step -> ETTP(NBPT,JVLS(NVUS))
!     preceding time step -> ETTPA(NBPT,JVLS(NVUS))
!
!     NBPT number of particle < NBPART
!     NVUS number of supplementary variable y NVLS
!     * supplementary stochastic PDEs are defined in USLAED
nvls = 0

! 5.2 stationnary characteristics of continuous phase
!
! indicates the steady (=1) or unsteady (=0) state of the continuous 
! phase flow in particular, 
! ISTTIO = 1 is needed in order to:
! calculate stationary statistics in the volume or at the boundaries 
! (starting respectively from the Lagrangian iterations NSTIST and NSTBOR)
! calculate time-averaged two-way coupling source terms (from the Lagrangian iteration NSTITS)
! useful if IILAGR=1 or IILAGR=2 (if IILAGR=3, then ISTTIO=1 automatically)

if (iilagr.ne.3) isttio = 0

! 5.3 influence of the particle phase to the continous phase

if (iilagr.eq.2) then

! number of absolute Lagrangian iterations (including the restarts) after 
! which a time-average of the two-way coupling source terms is calculated indeed, 
! if the flow is steady (ISTTIO=1), the average quantities that appear in the two-way 
! coupling source terms can be calculated over different time steps, in order to get a 
! better precision if the number of absolute Lagrangian iterations is strictly inferior to 
! NSTITS, the code considers that the flow has not yet reached its steady state 
! (transition period) and the averages appearing in the source terms are reinitialised at 
! each time step, as it is the case for unsteady flows (ISTTIO=0) 
! useful if IILAGR = 2 and ISTTIO = 1
nstits = 1

! activation (=1) or not (=0) of the two-way coupling on the dynamics 
! of the continuous phase
!
ltsdyn = 0
!
! activation (=1) or not (=0) of the two-way coupling on the mass useful if 
! IILAGR = 2, IPHYLA = 1 and IMPVAR = 1
! COUPLAGE RETOUR SUR LA MASSE (SI IPHYLA = 1 ET IMPVAR = 1)
!
if ((iphyla.eq.1 .and. (impvar.eq.1 .or. idpvar.eq.1)) .or. iphyla.eq.3) ltsmas = 1
!
! if IPHYLA = 1 and ITPVAR = 1, LTSTHE activates (=1) or not (=0) the two-way coupling 
! on temperature if IPHYLA = 2, LTSTHE activates (=1) or not (=0) the two-way coupling 
! on the eulerian variables related to pulverised coal combustion useful if IILAGR = 2    
!
if((iphyla.eq.1 .and. itpvar.eq.1) .or. iphyla.eq.2 .or. iphyla.eq.3) ltsthe = 1
!
endif ! iilagr.eq.2 -> two-way coupling
!
!
! volume statistics
!
! activation (=1) or not (=0) of the calculation of the volume statistics related
! to the dispersed phase if ISTALA = 1, the calculation of the statistics is
! activated starting from the absolute iteration (including the restarts) by
! default, the statistics are not stationary (reset to zero at every Lagrangian
! iteration). But if ISTTIO=1, since the flow is steady, the statistics will be
! averaged overt he different time steps the statistics represent the significant
! results on the particle cloud
istala = 0
!
!
if (istala.eq.1) then
! every cell of the calculation domain contains a certain quantity of particles,
! representing a certain statistical weight (sum of the statistical weights of
! all the particles present in the cell). SEUIL is the limit statistical weight
! value, below which the contri- bution of the cell in term of statistical weight
! is not taken into account in the volume statistics (for the complete turbulent
! dispersion model, in the Poissons equation used to correct the mean velocities
! or in the listing and post-processing outputs) useful if ISTALA = 1
!
        seuil = 0.d0
!
! absolute Lagrangian iteration number (includings the restarts) after which the
! calculation of the volume statistics is aC calculation of the volume
! statistics is activatedd
        idstnt = 1

! absolute Lagrangian iteration number (includings the restarts) after which the
! volume statistics are cumulated over time (they are then said to be stationary)
! if the absolute Lagrangian iteration number is lower than NSTIST, or if the flow
! is unsteady (ISTTIO=0), the statistics are reset to zero at every Lagrangian
! iteration (the volume statistics are then said to be non-stationary) useful if
! ISTALA=1 and ISTTIO=1
	
      nstist = idstnt
!
!
!   5.4.2 number of statistical variables and the identifiers in the result file
!
!    NOMLAG : name of mean value
!    NOMLAV : name of variance
!    IHSLAG : sortie des enregistrements sur les capteurs definis
!             dans USINI1
!
        IPV  =  1
        NOMLAG(IPV)  = 'MeanPtVelocityX'
        NOMLAV(IPV)  = 'VarPtVelocityX'
        IHSLAG(IPV)  = 2
!
        IPV  = IPV  + 1
        NOMLAG(IPV)  = 'MeanPtVelocityY'
        NOMLAV(IPV)  = 'VarPtVelocityY'
        IHSLAG(IPV)  = 2
!
        IPV  = IPV  + 1
        NOMLAG(IPV)  = 'MeanPtVelocityZ'
        NOMLAV(IPV)  = 'VarPtVelocityZ'
        IHSLAG(IPV)  = 2
!
        IPV  = IPV  + 1
        NOMLAG(IPV)  = 'MoTauVol'
        NOMLAV(IPV)  = 'VaTauVol'
        IHSLAG(IPV)  = 2
!
        IPV  = IPV  + 1
        NOMLAG(IPV)  = 'MoTpsSej'
        NOMLAV(IPV)  = 'VaTpsSej'
        IHSLAG(IPV)  = 2
!
!   2) paricular physic models
!         mean and variance of temperature, diameter and mass
!
        IF (IPHYLA.EQ.1) THEN
!
          IF (ITPVAR.EQ.1) THEN
            IPV  = IPV  + 1
            NOMLAG(IPV) = 'MeanPtTemp'
            NOMLAV(IPV) = 'VaTempPt'
            IHSLAG(IPV)  = 2
          ENDIF
          IF (IDPVAR.EQ.1) THEN
            IPV  = IPV  + 1
            NOMLAG(IPV) = 'MeanPtDiameter'
            NOMLAV(IPV) = 'VaDiamPt'
            IHSLAG(IPV)  = 2
          ENDIF
          IF (IMPVAR.EQ.1) THEN
            IPV  = IPV  + 1
            NOMLAG(IPV) = 'MeanPtMass'
            NOMLAV(IPV) = 'VaMassPt'
            IHSLAG(IPV)  = 2
          ENDIF
!
        ELSE IF (IPHYLA.EQ.2) THEN
!
!   3) pulverised coal (IPHYLA = 2) :
!         Moyenne et variance de la temperature
!         Moyenne et variance de la masse de charbon reactif
!         Moyenne et variance de la masse de coke
!         Moyenne et variance du diametre du coeur retrecissant
!
          IPV  = IPV  + 1
          NOMLAG(IPV) = 'MoTempPt'
          NOMLAV(IPV) = 'VaTempPt'
          IHSLAG(IPV)  = 2
!
          IPV  = IPV  + 1
          NOMLAG(IPV) = 'MoMchPt'
          NOMLAV(IPV) = 'VaMchPt'
          IHSLAG(IPV)  = 2
!
          IPV  = IPV  + 1
          NOMLAG(IPV) = 'MoMcokPt'
          NOMLAV(IPV) = 'VaMcokPt'
          IHSLAG(IPV)  = 2
!
          IPV  = IPV  + 1
          NOMLAG(IPV) = 'MoDckPt'
          NOMLAV(IPV) = 'VaDckPt'
          IHSLAG(IPV)  = 2
!
        ENDIF
!
!   4) VARIABLES STATISTIQUES VOLUMIQUES SUPPLEMENTAIRES :
!       * Si l'utilisateur souhaite des calculs de statistiques
!         autres que ceux fournis en standard, il doit
!         1) donner leur nombre NVLSTS,  2) renseigner leur nom,
!         3) renseigner IHSLAG
!         et 4) intervenir dans les sous-programmes utilisateur
!         USLAST.F et USLAEN.F pour programmer ses nouvelles
!         statistiques (voir les exemples).
!       * Nombre maximal de statistiques supplementaires : 20
!         (sinon changer le parametre NUSSTA dans l'include lagpar.h)
!
        NVLSTS = 0
!
        IF (NVLSTS.GT.0) THEN
          DO II = 1,NVLSTS
            ILVU(II) = IPV + II
            WRITE(NOMLAG(ILVU(II)),'(A6,I4.4)') 'MoyLag',II
            WRITE(NOMLAV(ILVU(II)),'(A6,I4.4)') 'VarLag',II
            IHSLAG(ILVU(II))  = 1
          ENDDO
          IPV = IPV + NVLSTS
        ENDIF
!
!   5) Par defaut, statistique TOUJOURS calculee :
!         Somme du poids statistiques associ aux particules
!            (i.e. nombre de particules par cellules)
!
        IPV  = IPV  + 1
        NOMLAG(IPV)  = 'SomPoids'
        IHSLAG(IPV)  = 1
!
!   6) STATISTIQUES PAR GROUPE :
!       * Si l'utilisateur souhaite des calculs de statistiques
!         par groupe de particule (par defaut aucune statistique par groupe),
!         il doit :
!         1) donner NBCLST le nombre de groupe (limite a 100)
!         2) preciser dans USLAG2 le groupe auquel appartient chaque particule
!              a l'aide du tableau IUSLAG
!
!      * ATTENTION : NBCLST ne peut pas etre change lors d'une suite de
!        calcul (ISUILA=1) meme si le calcul des statistiques n'est pas
!        encore enclenche (ISTALA=0)
!
        NBCLST = 0
!
      ENDIF
!
!
!=======================================================================
! 6.particle entry
!=======================================================================
!
! activates (=1) or not (=0) the continuous injection of particles this
! option allows to inject particles continuously during the duration of the
! Lagrangian time step DTP rather than only once at the beginning of the
! Lagrangian iteration. It helps avoiding the fractioning of the particle cloud
! close to the injection areas
!
      INJCON = 1
!
! 7. particle floning/fusioning
!    activation of russian roulette
!    default deactivated: 0
!    activated : 1 sans calcul de Y+
!                2 avec calcul de Y+
      IROULE = 0
!
!===============================================================================
! 7.2 Secondary Atomization
!===============================================================================
! isecat = 0 - disable secondary atomization
! isecat = 1 - enable secondary atomization
!isecat = 0

!===============================================================================
! 8. numerical treatment of dispersed phase
!===============================================================================
!
! order of integration scheme
!       NORDRE = 1  
!       NORDRE = 2 

      NORDRE = 1

! activation (=1) or not (=0) of the solution of a Poisson's equation for the 
! correction of the particle instantaneous velocities (in order to obtain a null divergence)
!     ATTENTION : do not change ILAPOI
      ILAPOI = 0

!===============================================================================
! 9. options for turbulent dispersion
!===============================================================================

!
! ATTENTION : DANS CETTE VERSION, LA DISPERSION TURBULENTE NE
! FONCTIONNE QUE SI LA PHASE CONTINUE EST CALCULEE
! AVEC UN MODELE k-eps OU Rij-eps
! activation (=1) or not (=0) of the particle turbulent dispersion 
! the turbulent dispersion is compatible only with the RANS turbulent models 
! (k-e, Rij, v2f or k-w)
      IDISTU = 0
!
!
!-->  DISPERSION TURBULENTE IMPOSEE A CELLE DU FLUIDE
!
!  IDIFFL=1 suppresses the crossing trajectory effect, making turbulent 
!  dispersion for the particles identical to the turbulent diffusion of 
!  fluid particles useful if IDISTU=1
!
      IDIFFL = 0

! activates (>0) or not (=0) the complete turbulent dispersion model when MODCPL 
! is strictly positive, its value is interpreted as the absolute Lagrangian time 
! step number (including restarts) after which the complete model is applied since 
! the complete model uses volume statistics, MODCPL must either be 0 or be larger than IDSTNT
!     MODCPL = 0 incomplete model
      MODCPL = 0
!
! x,y or z direction of the complete model it corresponds to the main directions of the flow

      IF (MODCPL.GT.0) IDIRLA = 1


! =============================================================================
! 10. forces on the particles 
!===============================================================================
!
!     activation of particle forces
! - van der Waals
! - electrostatic forces
!     Developer-Option
!
      LADLVO = 0
!
!-->  Constante pour les forces de Van der Waals
!
!    Constante d'Hamaker Particule/Eau/substrat :
!
      CSTHAM = 6.D-20
!
!-->  Constante pour les forces Electrostatiques
!
!    Constante de Faradet (C/mol)
!
      CSTFAR = 9.648D4
!
!    Constante dielectrique du vide :
!
      EPSVID = 8.854D-12
!
!    Constante dielectrique de l'eau
!
      EPSEAU = 80.10D0
!
!    Potentiel solide 1 (Volt)
!
      PHI1 = 50.D-3
!
!    Potentiel solide 2 (Volt)
!
      PHI2 = -50.D-3
!
!    FORCE IONIQUE (mol/l)
!
      FION = 1.D-2
!
!    DISTANCE DE COUPURE
!      dans la litterature elle est egale  : 1.58D-10
!                                        ou   1.65D-10
!
      DCOUP = 1.58D-10
!
!    DENSITE DE CHARGE
!
      SIGCH = 0.D0
!
!   Distance minimum entre la particule et la paroi
!
      DPARMN = 1.D-10
!
!
!===============================================================================
! 11. brownian motion 
!===============================================================================

!   (=1) activation of brownian motion
!    ATTENTION : OPTION DEVELOPPEUR UNIQUEMENT
      LAMVBR = 0

!===============================================================================
! 12. POST-PROCESSING
!===============================================================================
! 
!
! 12.1 post-processing of particle trajectories and displacement
!
! time consuming
!
!   12.1.1 PARAMETRES GENERAUX
!   ~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!     (=1) trajectories are calculated
      IENSI1 = 1
!
!     (=1) particle displacements are calculated
      IENSI2 = 0
!
! number of particles selected for post-processing display in trajectory or 
! movement mode NBVIS must be lower than NBPMAX and NLISTE 
! (set to 500 in lagpar.h and not to be modified)
      NBVIS = NLISTE
!
! output period for the post-processing in trajectory or movement mode may 
! be useful to diminish the size of the post-processing files
      NVISLA = 1
!
! contains the index-numbers of the particles selected for the display in trajectory 
! or movement mode useful if IENSI1 = 1 or IENSI2 = 1
!   > EXEMPLE 1 :
!     je veux voir les NBVIS 1eres
!
      DO II = 1, NBVIS
        LISTE(II) = II
      ENDDO
!
!   > EXEMPLE 2 :
!     je veux voir la 3 5 67 23 1 76 35 36 ...etc..
!
!     LISTE(1) = 3
!     LISTE(2) = 5
!     LISTE(3) = 67
!     LISTE(4) = 23
!     LISTE(5) = 1
!     LISTE(6) = 76
!     LISTE(7) = 35
!     LISTE(8) = 36
!     ...etc...
!
!   > REMARQUE : les trous, les repetitions dans le tableau LISTE seront
!                suprimes, et les numeros seront ranges par ordre
!                croissant.
!
! associate scalars to the display of particle trajectories
!
!     VARIABLE : velocity of continuum phase
!     (DEFAUT NON : 0 ; OUI : 1)
!
      IVISV1  = 1
!
!     VARIABLE : particle velocity
!     (DEFAUT NON : 0 ; OUI : 1)
!
      IVISV2  = 1
!
!     VARIABLE : residence time
!     (DEFAUT NON : 0 ; OUI : 1)
!
      IVISTP  = 1
!
!     VARIABLE : diameter
!     (DEFAUT NON : 0 ; OUI : 1)
!
      IVISDM  = 1
!
!     VARIABLE : temperature
!     (DEFAUT NON : 0 ; OUI : 1)
      IF (IPHYLA.EQ.1 .AND. ITPVAR.EQ.1) IVISTE  = 0
!
!     VARIABLE : mass
!     (DEFAUT NON : 0 ; OUI : 1)
!
      IVISMP  = 1
!
!
      IF (IPHYLA.EQ.2) THEN
!
!       VARIABLE CHARBON : TEMPERATURE EN DEGRES CELSIUS
!       (DEFAUT NON : 0 ; OUI : 1)
!
        IVISHP = 0
!
!       VARIABLE CHARBON : DIAMETRE DU COEUR RETRECISSANT
!       (DEFAUT NON : 0 ; OUI : 1)
!
        IVISDK  = 0
!
!       VARIABLE CHARBON : MASSE DE CHARBON REACTIF
!       (DEFAUT NON : 0 ; OUI : 1)
!
        IVISCH  = 0
!
!       VARIABLE CHARBON : MASSE DE COKE
!       (DEFAUT NON : 0 ; OUI : 1)
!
        IVISCK  = 0
!
      ENDIF

      if (iphyla.eq.3) then
        iviste = 1
      endif 
!
!
! Display of the particle/boundary interactions and the statistics 
! at the boundaries

! activation (=1) or not (=0) of the recording of the particle/boundary
! interactions in PARBOR, and of the calculation of the statistics at the
! corresponding boundaries, for post-processing (EnSight6 format) By default, the
! statistics are non-stationary (reset to zero at every Lagrangian itera- tion).
! They may be stationary if ISTTIO=1 (i.e. calculation of a cumulated value over
! time, and then calculation of an average over time or over the number of
! interactions with the boundary)
! 
! (DEFAUT NON : 0 ; OUI : 1)
!
      IENSI3 = 0
!
! number of absolute Lagrangian iterations (including the restarts) after which
! the statistics at the boundaries are considered stationary and are averaged
! (over time or over the number of interactions) If the number of absolute
! Lagrangian iterations is lower than NSTBOR, or if IST- TIO=0, the statistics are
! reset to zero at every Lagrangian iteration (non-stationary statistics) useful
! if IENSI3=1 and ISTTIO=1

      NSTBOR = 1
!
! every boundary face of the mesh undergoes a certain number of interactions with
! particles, expressed in term of statistical weight (sum of the statistical
! weights of all the particles which have interacted with the boundary face).
! SEUILF is the limit statistical weight value, below which the contribution of
! the face is not taken into account in the statistics at the boundaries for
! post-processing 
!     (DEFAUT : SEUILF = 0.D0)
!
      SEUILF = 0.D0
!
!
!   12.2.2 INFORMATIONS A ENREGISTRER
!   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! activation (=1) or not (=0) of the recording of the number of 
! particle/boundary interactions, and of the calculation of the 
! associated boundary statistics. INBRD = 1 is a compulsory condition 
! to use the particulate average IMOYBR = 2 the selection of the type of 
! interactions that are to be recorded is specified in the subroutine uslabo
! useful if IENSI3=1
!  
!     NOMBRE D'INTERACTIONS PARTICULES/FRONTIERES
!     (DEFAUT NON : 0 ; OUI : 1)
      INBRBD = 0
!
!     FLUX DE MASSE PARTICULAIRE LIE AUX INTERACTIONS
!     PARTICULES/FRONTIERES
!     (DEFAUT NON : 0 ; OUI : 1)
      IFLMBD = 0
!
!     ANGLE ENTRE LA VITESSE DE LA PARTICULE
!     ET LE PLAN DE LA FACE FRONTIERE
!     (DEFAUT NON : 0 ; OUI : 1)
      IANGBD = 0
!
!     NORME DE LA VITESSE DE LA PARTICULE AU MOMENT
!     DE SON INTERACTION AVEC LA FACE FRONTIERE
!     (DEFAUT NON : 0 ; OUI : 1)
      IVITBD = 0
!
!     MASSE DE GRAINS DE CHARBON ENCRASSES
!     (DEFAUT NON : 0 ; OUI : 1)
       IF (IPHYLA.EQ.2 .AND. IENCRA.EQ.1) IENCBD = 0
!
!     INFORMATIONS UTILISATEUR SUPPLEMENTAIRES A ENREGISTREES
!     (PAR EXEMPLE TAUX D'EROSION, TEMPERATURE...)
!     * ces enregistrements supplementaires sont stokees dans
!       le tableau PARBOR,
!     * on renseigne ici le nombre NUSBOR d'enregistrements
!       supplementaires,
!     * la limite supperieure de ce nombre est NUSBRD = 10
!       (fixee dans lagpar.h),
!     * voir un exemple de code d'un enregistrement supplementaire
!       dans le sous-programme USLABO.
!
      NUSBOR = 0
!
!
!   12.2.3 NOM DES ENREGISTREMENTS POUR AFFICHAGE,
!          MOYENNE EN TEMPS OU MOYENNE PARTICULAIRE
!          DES STATISTIQUES AUX FRONTIERES
!   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!    * A priori l'utilisateur n'intervient que dans les infos
!      utilisateur supplementaires a enregistrer : il doit
!      donner le nom de l'enregistrement ainsi que le type
!      de moyenne que l'on souhaite lui appliquer pour les affichages
!      listing et en fin de calcul pour le post-processing.
!
!    * ATTENTION ce nom est utilise pour retrouver les informations
!      dans le fichier suite de calcul, si un nom est modifie
!      entre deux calculs, le resultat concerne n'est pas relu
!      (et est donc perdu).
!
!    * La moyenne appliquee est donnee par l'intermediaire du
!      tableau IMOYBR :
!       - si IMOYBR(IUSB(II)) = 0 -> pas de moyenne appliquee
!       - si IMOYBR(IUSB(II)) = 1 -> on applique une moyenne temporelle,
!               c'est a dire que la statistique est divisee par le
!               dernier pas de temps dans le cas d'un enregistrement
!               instationnaire, ou stationnaire mais avec un nombre
!               d'iterations inferieur a NSTBOR ; ou que la statistique
!               est divisee par le temps d'enregistrement
!               stationnaire dans le cas stationnaire.
!       - si IMOYBR(IUSB(II)) = 2 -> on applique une moyenne
!               particulaire, c'est a dire qu'on divise la statistique
!               par le nombre d'interactions particules/frontieres
!               enregistrees (en terme de poids statistique)
!               dans PARBOR(NFABOR,INBR) (cf. USLABO).
!               Pour utiliser cette moyenne il faut que INBRBD=1.
!    * Les sauvegardes dans le fichier suite de calcul sont faites
!      sans application de cette moyenne.
!    * La moyenne est appliquee si le nombre d'interactions (en poids
!      statistique) de la face de bord consideree est strictement
!      superieur a SEUILF, sinon la moyenne est mise a zero.

ipv = 0

if (iensi3.eq.1) then

        IF (INBRBD.EQ.1) THEN
          IPV = IPV + 1
          INBR = IPV
          NOMBRD(INBR) = 'nombreImpact'
          IMOYBR(INBR) = 0
        ENDIF

        IF (IFLMBD.EQ.1) THEN
          IPV = IPV + 1
          IFLM = IPV
          NOMBRD(IFLM) = 'MassFlux'
          IMOYBR(IFLM) = 1
        ENDIF

        IF (IANGBD.EQ.1) THEN
          IPV = IPV + 1
          IANG = IPV
          NOMBRD(IANG) = 'IncidentAngle'
          IMOYBR(IANG) = 1
        ENDIF

        IF (IVITBD.EQ.1) THEN
          IPV = IPV + 1
          IVIT = IPV
          NOMBRD(IVIT) = 'IncidentVelocity'
          IMOYBR(IVIT) = 1
        ENDIF

        IF (IENCBD.EQ.1) THEN
          IPV = IPV + 1
          IENC = IPV
          NOMBRD(IENC) = 'SootMass'
          IMOYBR(IENC) = 0
        ENDIF

        IF (NUSBOR.GT.0) THEN
          DO II = 1,NUSBOR
            IPV = IPV + 1
            IUSB(II) = IPV
            WRITE(NOMBRD(IUSB(II)),'(A8,I4.4)') 'enrSupp',II
            IMOYBR(IUSB(II)) = 0
          ENDDO
        ENDIF

endif

!===============================================================================
! 13. reports of lagrangian module
!===============================================================================
! periodicity of listing of lagragian particles

      NTLAL = 1

!=======================================================================
!
      RETURN
!
      END
